==> tdesvn-trinity_14.0.5.orig.tar.xz: tdesvn-trinity-14.0.5/src/ksvnwidgets/revertform_impl.h <==
/***************************************************************************
 *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef _REVERT_FORM_IMPL_H
#define _REVERT_FORM_IMPL_H

#include "revertform.h"
#include "svnqttypes.hpp"

class TQStringList;

class RevertFormImpl:public RevertForm
{
    Q_OBJECT
  
public:
    RevertFormImpl(TQWidget*parent=0,const char*name=0);
    virtual ~RevertFormImpl();
    svn::Depth getDepth()const;
    void setDispList(const TQStringList&_list);
};

#endif

==> tdesvn-trinity_14.1.0.orig.tar.xz: tdesvn-trinity-14.1.0/src/ksvnwidgets/revertform_impl.h <==
/***************************************************************************
 *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef _REVERT_FORM_IMPL_H
#define _REVERT_FORM_IMPL_H

#include "revertform.h"
#include "svnqttypes.h"

class TQStringList;

class RevertFormImpl:public RevertForm
{
    Q_OBJECT
  
public:
    RevertFormImpl(TQWidget*parent=0,const char*name=0);
    virtual ~RevertFormImpl();
    svn::Depth getDepth()const;
    void setDispList(const TQStringList&_list);
};

#endif
